# Run in a container

Pre-built containers with {\{repo_name}} and its dependencies already
installed are available on [Github Container Registry](https://ghcr.io/mcipc-tools/mcwb).

## Starting the container

To pull the container from github container registry and run:

```
$ docker run ghcr.io/mcipc-tools/mcwb:main --version
```

To get a released version, use a numbered release instead of `main`.
